Struct amazon_sp_vendor_direct_fulfillment_shipping::models::shipment_details::ShipmentDetails
source · [−]pub struct ShipmentDetails {
pub shipped_date: String,
pub shipment_status: ShipmentStatus,
pub is_priority_shipment: Option<bool>,
pub vendor_order_number: Option<String>,
pub estimated_delivery_date: Option<String>,
}Expand description
ShipmentDetails : Details about a shipment.
Fields
shipped_date: StringThis field indicates the date of the departure of the shipment from vendor’s location. Vendors are requested to send ASNs within 30 minutes of departure from their warehouse/distribution center or at least 6 hours prior to the appointment time at the Amazon destination warehouse, whichever is sooner. Shipped date mentioned in the Shipment Confirmation should not be in the future.
shipment_status: ShipmentStatusIndicate the shipment status.
is_priority_shipment: Option<bool>Provide the priority of the shipment.
vendor_order_number: Option<String>The vendor order number is a unique identifier generated by a vendor for their reference.
estimated_delivery_date: Option<String>Date on which the shipment is expected to reach the buyer’s warehouse. It needs to be an estimate based on the average transit time between the ship-from location and the destination. The exact appointment time will be provided by buyer and is potentially not known when creating the shipment confirmation.
Implementations
sourceimpl ShipmentDetails
impl ShipmentDetails
sourcepub fn new(
shipped_date: String,
shipment_status: ShipmentStatus
) -> ShipmentDetails
pub fn new(
shipped_date: String,
shipment_status: ShipmentStatus
) -> ShipmentDetails
Details about a shipment.